# MarketPsych: Power of minds over markets

MarketPsych produces the global standard in financial sentiment and ESG data from the news and social media information flow. We serve global funds, corporations, banks and brokerages in over 25 countries. Our products are distributed exclusively, and in partnership, with [Refinitiv](https://www.refinitiv.com/en), a global provider of financial market data and infrastructure.

MarketPsych's proprietary NLP engine evaluates thousands of market moving themes, which are further aggregated into scores. The scores form time-series that are updated every 60 seconds. Each score represents the scale and direction of the media focus on complex themes, including sentiments, sustainability and price. They can be translated directly into spreadsheets or charts that can be monitored by traders, risk managers or analysts – or they can be plugged straight into your algorithms for low frequency or longer-term asset allocation or sector rotation decisions.

For more details check out our [website](https://www.marketpsych.com/).

## Features

* **Wide coverage**:
    * 252 countries
    * 36,000+ global companies, sectors, and ETFs
    * 62 stock indexes and sovereign bonds
    * 44 currencies
    * 51 commodities
    * 300+ cryptocurrencies
* **Long history**: 1998 to the present
* **Multi-language**: sources in 12 languages
* **AI-based**: machine learning NLP system
* **Highly granular**: 100+ scores
* **Real-time**: 60-second, hourly, and daily updates
* **Sources**: 6000+ news and social media outlets

## Install MarketPsych supporting library

### pip  
```
pip install marketpsych
```

## Modules
If using Jupyter Notebook, be sure to have version >= 6.0. If using Jupyter Lab, be sure to have version >= 3.0.

### sftp
This library assists with loading your trialling data from SFTP directly into a Jupyter notebook.

### mpwidgets
This library provides widgets through which you can set your data parameters inside a Jupyter notebook.